==> rbuild-0.0.2.tgz: package/lib/task.js <==
var readFile, writeFile, watchFile, stat, Bundler, Task, TaskPool, _ref;
_ref = require('fs'), readFile = _ref.readFile, writeFile = _ref.writeFile, watchFile = _ref.watchFile, stat = _ref.stat;
Bundler = require('./bundler').Bundler;
function writeResult(path, data, cbk){
  return writeFile(path, data, 'utf-8', function(err){
    if (err) {
      console.log(path + ": " + err);
      return;
    }
    return typeof cbk == 'function' ? cbk() : void 8;
  });
}
/**
 *  @class Task
 */
Task = (function(){
  /**
   *  @constructor
   */
  Task.displayName = 'Task';
  var prototype = Task.prototype, constructor = Task;
  function Task(_arg){
    var _ref;
    this.dependencies = (_ref = _arg.dependencies) != null
      ? _ref
      : [], this.callback = _arg.callback, this.watch = _arg.watch;
    this.watching = false;
  }
  /**
   *
   */
  prototype.run = (function(){
    function run(){
      var f, _i, _ref, _len, _this = this;
      if (this.watch && !this.watching) {
        this.watching = true;
        for (_i = 0, _len = (_ref = this.dependencies).length; _i < _len; ++_i) {
          f = _ref[_i];
          watchFile(f, _fn);
        }
      }
      return this.callback();
      function _fn(curr, prev){
        if (curr.mtime > prev.mtime) {
          return _this.callback();
        }
      }
    }
    return run;
  }());
  return Task;
}());
/**
 *  @class TaskPool
 */
TaskPool = (function(){
  /**
   *  @constructor
   */
  TaskPool.displayName = 'TaskPool';
  var prototype = TaskPool.prototype, constructor = TaskPool;
  function TaskPool(_arg){
    this.watch = _arg.watch;
    this.tasks = [];
  }
  /**
   *
   */
  prototype.createTaskForFile = (function(){
    function createTaskForFile(file, outfile, callback){
      function fileCallback(error){
        return stat(file, function(err_in, istat){
          return stat(outfile, function(err_out, ostat){
            if (!err_out && istat.mtime <= ostat.mtime) {
              console.log("= " + file);
              return;
            }
            return readFile(file, 'utf-8', function(err, data){
              var res;
              if (err) {
                console.log(file + ": " + err);
                return;
              }
              try {
                res = callback(data);
                return writeResult(outfile, res, function(){
                  return console.log(new Date().toLocaleTimeString() + ": " + file + " => " + outfile);
                });
              } catch (e) {
                return console.log(file + ": " + e);
              }
            });
          });
        });
      }
      return this.addTask(new Task({
        dependencies: [file],
        callback: fileCallback
      }));
    }
    return createTaskForFile;
  }());
  /**
   *
   */
  prototype.createBundleTask = (function(){
    function createBundleTask(outfile, files, extensions){
      var bundler;
      bundler = new Bundler({
        files: files,
        watch: this.watch,
        extensions: extensions
      });
      return this.addTask(new Task({
        dependencies: [],
        callback: function(){
          return bundler.bundle(function(err, data){
            return writeResult(outfile, data, function(){
              return console.log("* Wrote " + outfile);
            });
          });
        }
      }));
    }
    return createBundleTask;
  }());
  /**
   *
   */
  prototype.addTask = (function(){
    function addTask(task){
      this.tasks.push(task);
      task.watch = this.watch;
      task.run();
      return task;
    }
    return addTask;
  }());
  return TaskPool;
}());
exports.Task = Task;
exports.TaskPool = TaskPool;

==> rbuild-0.0.3.tgz: package/lib/task.js <==
var readFile, writeFile, watchFile, unwatchFile, stat, Bundler, BundleFile, Task, TaskPool, _ref, __indexOf = [].indexOf || function(x){
  var i = -1, l = this.length;
  while (++i < l) if (this.hasOwnProperty(i) && this[i] === x) return i;
  return -1;
};
_ref = require('fs'), readFile = _ref.readFile, writeFile = _ref.writeFile, watchFile = _ref.watchFile, unwatchFile = _ref.unwatchFile, stat = _ref.stat;
_ref = require('./bundler'), Bundler = _ref.Bundler, BundleFile = _ref.BundleFile;
function writeResult(path, data, cbk){
  return writeFile(path, data, 'utf-8', function(err){
    if (err) {
      console.log(path + ": " + err);
      return;
    }
    return typeof cbk == 'function' ? cbk() : void 8;
  });
}
/**
 *  @class Task
 */
Task = (function(){
  /**
   *  @constructor
   */
  Task.displayName = 'Task';
  var prototype = Task.prototype, constructor = Task;
  function Task(_arg){
    var _ref;
    this.dependencies = (_ref = _arg.dependencies) != null
      ? _ref
      : [], this.callback = _arg.callback, this.watch = _arg.watch;
    this.watching = false;
  }
  /**
   *
   */
  prototype.run = (function(){
    function run(){
      var f, _i, _ref, _len, _this = this;
      if (this.watch && !this.watching) {
        this.watching = true;
        for (_i = 0, _len = (_ref = this.dependencies).length; _i < _len; ++_i) {
          f = _ref[_i];
          watchFile(f, _fn);
        }
      }
      return this.callback();
      function _fn(curr, prev){
        if (curr.mtime > prev.mtime) {
          return _this.callback();
        }
      }
    }
    return run;
  }());
  return Task;
}());
/**
 *  @class TaskPool
 */
TaskPool = (function(){
  /**
   *  @constructor
   */
  TaskPool.displayName = 'TaskPool';
  var prototype = TaskPool.prototype, constructor = TaskPool;
  function TaskPool(_arg){
    this.watch = _arg.watch;
    this.tasks = [];
  }
  /**
   *
   */
  prototype.createTaskForFile = (function(){
    function createTaskForFile(file, outfile, callback){
      function fileCallback(error){
        return stat(file, function(err_in, istat){
          return stat(outfile, function(err_out, ostat){
            if (!err_out && istat.mtime <= ostat.mtime) {
              console.log("= " + file);
              return;
            }
            return readFile(file, 'utf-8', function(err, data){
              var res;
              if (err) {
                console.log(file + ": " + err);
                return;
              }
              try {
                res = callback(data);
                return writeResult(outfile, res, function(){
                  return console.log(new Date().toLocaleTimeString() + " => " + file + " > " + outfile);
                });
              } catch (e) {
                return console.log(file + ": " + e);
              }
            });
          });
        });
      }
      return this.addTask(new Task({
        dependencies: [file],
        callback: fileCallback,
        watch: this.watch
      }));
    }
    return createTaskForFile;
  }());
  /**
   *
   */
  prototype.createBundleTask = (function(){
    function createBundleTask(outfile, files, extensions){
      var bundler, watched, _this = this;
      bundler = new Bundler({
        files: files,
        extensions: extensions
      });
      watched = [];
      files = [];
      return this.addTask(new Task({
        dependencies: [],
        callback: (function(){
          function recompileFiles(){
            return bundler.bundle(function(err, data){
              var k, f, _res, _ref, _ref2, _i, _len;
              _res = [];
              for (k in _ref = (_ref2 = bundler.modules) != null
                ? _ref2
                : {}) {
                f = _ref[k];
                _res.push(f.realpath);
              }
              files = _res;
              for (_i = 0, _len = (_ref = files).length; _i < _len; ++_i) {
                f = _ref[_i];
                _fn(f);
              }
              return writeResult(outfile, data, function(){
                return console.log(new Date().toLocaleTimeString() + " => rewrote bundle " + outfile);
              });
              function _fn(f){
                if (__indexOf.call(watched, f) >= 0) {
                  return;
                }
                watchFile(f, function(cur, prev){
                  BundleFile.get(f).recompile = true;
                  if (cur.mtime > prev.mtime && __indexOf.call(files, f) >= 0) {
                    return recompileFiles();
                  }
                });
                return watched.push(f);
              }
            });
          }
          return recompileFiles;
        }())
      }));
    }
    return createBundleTask;
  }());
  /**
   *
   */
  prototype.addTask = (function(){
    function addTask(task){
      this.tasks.push(task);
      task.watch = this.watch;
      task.run();
      return task;
    }
    return addTask;
  }());
  return TaskPool;
}());
exports.Task = Task;
exports.TaskPool = TaskPool;
